@@ -14,6 +14,7 @@ from .configprovider import AioSmartDefaultsConfigStoreFactory
 from .credentials import AioCredentials, create_credential_resolver
 from .hooks import AioHierarchicalEmitter
 from .parsers import AioResponseParserFactory
+from .tokens import create_token_resolver
 from .utils import AioIMDSRegionProvider
 
 
@@ -47,6 +48,9 @@ class AioSession(Session):
             session_vars, event_hooks, include_builtin_handlers, profile
         )
 
+    def _create_token_resolver(self):
+        return create_token_resolver(self)
+
     def _create_credential_resolver(self):
         return create_credential_resolver(
             self, region_name=self._last_client_region_used
@@ -167,6 +171,7 @@ class AioSession(Session):
             )
         else:
             credentials = await self.get_credentials()
+        auth_token = self.get_auth_token()
         endpoint_resolver = self._get_internal_component('endpoint_resolver')
         exceptions_factory = self._get_internal_component('exceptions_factory')
         config_store = self.get_component('config_store')
@@ -200,6 +205,7 @@ class AioSession(Session):
             scoped_config=self.get_scoped_config(),
             client_config=config,
             api_version=api_version,
+            auth_token=auth_token,
         )
         monitor = self._get_internal_component('monitor')
         if monitor is not None:
